@@ -161,6 +161,7 @@ Variables
   QStringList sl_charsets;
   QStringList sl_last_used_charsets;
   QStringList sl_fif_history;
+  //QStringList sl_gtk_bookmarks;
 
   int fm_entry_mode;
 
@@ -759,6 +760,7 @@ Fn menu callbacks
   void fn_insert_time();
   void fn_case_up();
   void fn_case_down();
+  void fn_case_cap_sentences();
   void fn_sort_casecare();
   void fn_sort_casecareless();
   void fn_sort_casecare_sep();
